@@ -674,7 +674,6 @@ class GBPShell(app.App):
         subcommand = self.command_manager.find_command(argv)
         cmd_factory, cmd_name, sub_argv = subcommand
         cmd = cmd_factory(self, self.options)
-        err = None
         result = 1
         try:
             self.prepare_to_run_command(cmd)
@@ -810,8 +809,6 @@ class GBPShell(app.App):
 
         super(GBPShell, self).initialize_app(argv)
 
-        self.api_version = {'network': self.api_version}
-
         # If the user is not asking for help, make sure they
         # have given us auth.
         cmd_name = None
@@ -936,8 +933,8 @@ class GBPShell(app.App):
 
 def main(argv=sys.argv[1:]):
     try:
-        return GBPShell(NEUTRON_API_VERSION).run(map(encodeutils.safe_decode,
-                                                     argv))
+        return GBPShell(NEUTRON_API_VERSION).run(
+            list(map(encodeutils.safe_decode, argv)))
     except exc.NeutronClientException:
         return 1
     except Exception as e:
